@@ -185,7 +185,7 @@ Chake.nodes.each do |node|
   end
 
   desc 'apply <recipe> on #{hostname}'
-  task "apply:#{hostname}", [:recipe] => %i[recipe_input connect_common] do |_task, _args|
+  task "apply:#{hostname}", [:recipe] => [:recipe_input, :connect_common, "connect:#{hostname}"] do |_task, _args|
     maybe_decrypt(node) do
       node.apply($recipe_to_apply)
     end
@@ -193,19 +193,22 @@ Chake.nodes.each do |node|
   task "apply:#{hostname}" => converge_dependencies
 
   desc "run a command on #{hostname}"
-  task "run:#{hostname}", [:command] => %i[run_input connect_common] do
+  task "run:#{hostname}", [:command] => [:run_input, :connect_common, "connect:#{hostname}"] do
     node.run($cmd_to_run)
   end
 
   desc "Logs in to a shell on #{hostname}"
-  task "login:#{hostname}" => :connect_common do
+  task "login:#{hostname}" => [:connect_common, "connect:#{hostname}"] do
     node.run_shell
   end
 
   desc 'checks connectivity and setup on all nodes'
-  task "check:#{hostname}" => :connect_common do
+  task "check:#{hostname}" => [:connect_common, "connect:#{hostname}"] do
     node.run('sudo echo OK')
   end
+
+  # needs to be overridden in user projects
+  task "connect:#{hostname}"
 end
 
 task :run_input, :command do |_task, args|
