@@ -35,11 +35,15 @@ module Chake
     end
 
     def self.short_name
-      name.split('::').last.downcase
+      name.split('::').last.gsub(/([[:lower:]])([[:upper:]])/) do
+        first = Regexp.last_match(1)
+        last = Regexp.last_match(2).downcase
+        "#{first}-#{last}"
+      end.downcase
     end
 
-    def self.priority(new_prioriry = nil)
-      @priority ||= new_prioriry || 50
+    def self.priority(new_priority = nil)
+      @priority ||= new_priority || 50
     end
 
     def self.inherited(klass)
