@@ -6,7 +6,10 @@ module Chake
   class ConfigManager
     class Itamae < ConfigManager
       def converge
-        run_itamae(*node.data['itamae'])
+        recipes = node.data['itamae']
+        return if recipes.empty?
+
+        run_itamae(*recipes)
       end
 
       def apply(config)
